@@ -8,7 +8,6 @@ __all__ = [
     'bits2bytes',
     'bits2integer',
     'byte2int',
-    'bytes',
     'bytes2bits',
     'bytes2integer',
     'bytes2integers',
@@ -30,9 +29,8 @@ __all__ = [
     'integer2bytes',
     'integers2bytes',
     'integertypes',
-    'iteratebytes',
-    'iterateints',
     'ListContainer',
+    'ONWINDOWS',
     'PY',
     'PY2',
     'PY3',
@@ -44,19 +42,11 @@ __all__ = [
     'setGlobalPrintFullStrings',
     'setGlobalPrintPrivateEntries',
     'str2bytes',
-    'str2unicode',
     'stringtypes',
-    'supportshalffloats',
-    'supportsintenum',
-    'supportsintflag',
-    'supportsksyexport',
-    'supportskwordered',
-    'supportsnumpy',
     'swapbitsinbytes',
     'swapbytes',
     'swapbytesinbits',
     'trimstring',
     'unhexlify',
-    'unicode2str',
     'unicodestringtype',
 ]
